@@ -110,51 +110,62 @@ summary.chi <- function(object, digits=3, ...){
 }
 
 
-plot.chi <- function(x, which=1:2, lty = 1, cilty = 2, col = 1, spcases = FALSE, cicol = 1,
-                     xlim = c(0, 1), ylim1 = c(-1, 1), ylim2 = c(-1, 1),
-                     main1 = "Chi", main2 = "Chi Bar",
+plot.chi <- function(x, show=c("Chi"=TRUE,"ChiBar"=TRUE), lty = 1, cilty = 2, col = 1, spcases = TRUE, cicol = 1,
+                     xlim = c(0, 1), ylimChi = c(-1, 1), ylimChiBar = c(-1, 1),
+                     mainChi = "Chi", mainChiBar = "Chi Bar",
                      xlab = "Quantile", 
-                     ylab1 = expression(chi),#"Chi",
-                     ylab2 = expression(bar(chi)), #"Chi Bar",
+                     ylabChi = expression(chi(u)),#"Chi",
+                     ylabChiBar = expression(bar(chi)(u)), #"Chi Bar",
                      ask, ...){
 
-    show <- logical(2)
-    show[which] <- TRUE
-    lty <- c(cilty, lty, cilty)
-    col <- c(cicol, col, cicol)
-    nb.fig <- prod(par("mfcol"))
+  lty <- c(cilty, lty, cilty)
+  col <- c(cicol, col, cicol)
+  nb.fig <- prod(par("mfcol"))
 
 	if (is.R() & missing(ask)){
-		ask <- nb.fig < length(which) && dev.interactive()
-	}
-	else {
+	  ask <- nb.fig < sum(show) && dev.interactive()
+	}	else {
 		ask <- FALSE
 	}
-    if (ask) {
-        op <- par(ask = TRUE)
-        on.exit(par(op))
+  if (ask) {
+     op <- par(ask = TRUE)
+     on.exit(par(op))
+  }
+  ChiBarAsympIndep <- prod(tail(x$chibar[,3]) < 1)
+  if (show["ChiBar"]) {
+    matplot(x$quantile, x$chibar, type = "l", lty = lty, col = col, 
+            xlim = xlim, ylim = ylimChiBar, main = mainChiBar, xlab = xlab, 
+            ylab = ylabChiBar, ...)
+    if (spcases) {
+      segments(x$qlim[1], 0, x$qlim[2], 0, lty = 5, col = "grey")
+      segments(x$qlim[1], 1, x$qlim[2], 1, lty = 5, col = "grey")
+      segments(x$qlim[1],-1, x$qlim[2],-1, lty = 5, col = "grey")
     }
-    if (show[1]) {
-        matplot(x$quantile, x$chi, type = "l", lty = lty, col = col, xlim = xlim, 
-            ylim = ylim1, main = main1, xlab = xlab, ylab = ylab1, 
-            ...)
-        if (spcases) {
-            segments(x$qlim[1], 0, x$qlim[2], 0, lty = 5, col = "grey")
-            segments(x$qlim[1], 1, x$qlim[2], 1, lty = 5, col = "grey")
-            lines(x$quantile, x$chiulb, lty = 5, col = "grey")
-        }
+  }
+  if (show["Chi"]) {
+    if (ChiBarAsympIndep) {
+      col <- "grey"
+      cols <- "grey"
+    } else {
+      cols <- "black"
     }
-    if (show[2]) {
-        matplot(x$quantile, x$chibar, type = "l", lty = lty, col = col, 
-            xlim = xlim, ylim = ylim2, main = main2, xlab = xlab, 
-            ylab = ylab2, ...)
-        if (spcases) {
-            segments(x$qlim[1], 0, x$qlim[2], 0, lty = 5, col = "grey")
-            segments(x$qlim[1], 1, x$qlim[2], 1, lty = 5, col = "grey")
-            lines(x$quantile, x$chibarulb, lty = 5, col = "grey")
-        }
-    }
-    invisible()
+  
+    matplot(x$quantile, x$chi, type = "l", lty = lty, col = col, xlim = xlim, 
+            ylim = ylimChi, main = mainChi, xlab = xlab, ylab = ylabChi, 
+            col.lab=cols,col.main=cols,col.sub=cols,axes=FALSE,
+             ...)
+     box(col=cols)
+     axis(1,col=cols,col.axis = cols)
+     axis(2,col=cols,col.axis = cols)
+             
+     if (spcases) {
+       segments(x$qlim[1], 0, x$qlim[2], 0, lty = 5, col = "grey")
+       segments(x$qlim[1], 1, x$qlim[2], 1, lty = 5, col = "grey")
+       lines(x$quantile, x$chiulb, lty = 5, col = "grey")
+     }
+  }
+
+  invisible()
 }
 
 test.chi <- function(){
@@ -241,6 +252,8 @@ test.chi <- function(){
 test.plot.chi <- function(){
   chi <- chi(wavesurge)
   par(mfrow=c(1,2),pty="m")
-  res <- plot(chi,main1="Figure 8.11 of Coles (2001)\nChi")
+  res <- plot(chi,mainChiBar="Figure 8.11 of Coles (2001)\nChi Bar")
+  plot(chi, show=c("Chi"=FALSE,"ChiBar"=TRUE))
+  plot(chi, show=c("Chi"=TRUE,"ChiBar"=FALSE))
   checkEquals(res,NULL,msg = "plot.chi: check successful execution")
 }
