@@ -1,8 +1,9 @@
 `coefficients.migpd` <-
 function( object, ... ){
 	co <- sapply( object$models, function( x ) x$coefficients )
-	co <- rbind( object$mth, object$mqu, co )
-	dimnames( co ) <- list( c( "Threshold", "P(X < threshold)", "sigma", "xi" ) ,
+  up <- sapply( object$models, function( x) endPoint(x,verbose=FALSE) )
+	co <- rbind( object$mth, object$mqu, co, up )
+	dimnames( co ) <- list( c( "Threshold", "P(X < threshold)", "sigma", "xi", "Upper end point" ) ,
 							names( object$models ) )
 	co[ 3, ] <- exp( co[ 3 , ] )
 	co
