@@ -1,9 +1,21 @@
-gpd <- 
+gpd <- function(y, data, ...){
+  if (!missing(data)) {
+      y <- ifelse(deparse(substitute(y))== "substitute(y)", deparse(y),deparse(substitute(y)))
+      y <- formula(paste(y, "~ 1"))
+      y <- model.response(model.frame(y, data=data))
+  } 
+  UseMethod("gpd",y)
+}
+
+gpd.default <-
 function (y, data, th, qu, phi = ~1, xi = ~1,
-          penalty = "gaussian", prior = "gaussian", method = "optimize",
-		      cov="observed",
-          start = NULL, priorParameters = NULL, maxit = 10000, trace=NULL,
-          iter = 10500, burn=500, thin = 1, jump.cov, jump.const, verbose=TRUE) {
+          penalty = "gaussian", prior = "gaussian",
+          method = "optimize", cov="observed",
+          start = NULL, priorParameters = NULL,
+          maxit = 10000, trace=NULL,
+          iter = 40500, burn=500, thin = 4,
+          proposal.dist = c("gaussian", "cauchy"),
+          jump.cov, jump.const, verbose=TRUE,...) {
 
     theCall <- match.call()
 
@@ -51,14 +63,9 @@ function (y, data, th, qu, phi = ~1, xi = ~1,
 
     if (!missing(data)) {
       y <- deparse(substitute(y))
-    }
-    if (!missing(data)) {
       y <- formula(paste(y, "~ 1"))
       y <- model.response(model.frame(y, data=data))
-      if (missing(th)) {
-          th <- quantile(y, qu)
-      }
-
+     
       if (!is.R() & length(as.character(phi)) == 2 & as.character(phi)[2] == "1"){
         X.phi <- matrix(rep(1, nrow(data)), ncol=1)
       } else {
@@ -70,20 +77,26 @@ function (y, data, th, qu, phi = ~1, xi = ~1,
       } else {
         X.xi <- model.matrix(xi, data)
       }
-
-      X.phi <- X.phi[y > th, ]
-      X.xi <- X.xi[y > th, ]
     } else {
-      if (missing(th)) {
-          th <- quantile(y, qu)
+      if (length(as.character(phi)) == 2 & as.character(phi)[2] == "1"){  
+        X.phi <- matrix(ncol = 1, rep(1, length(y)))
+      } else {
+        X.phi <- model.matrix(phi)
+      }
+      if (length(as.character(xi)) == 2 & as.character(xi)[2] == "1"){
+        X.xi <- matrix(ncol = 1, rep(1, length(y)))
+      } else {
+        X.xi <- model.matrix(xi)
       }
-      X.phi <- matrix(ncol = 1, rep(1, length(y)))
-      X.xi <- matrix(ncol = 1, rep(1, length(y)))
-      X.phi <- X.phi[y > th, ]
-      X.xi <- X.xi[y > th, ]
     }
+    if (missing(th)) {
+        th <- quantile(y, qu)
+    }
+    X.phi <- X.phi[y > th, ]
+    X.xi <- X.xi[y > th, ]    
     rate <- mean(y > th)
 
+    allY <- y
     y <- y[y > th]
     if (!is.matrix(X.phi)) {
         X.phi <- matrix(X.phi, ncol = 1)
@@ -135,7 +148,7 @@ function (y, data, th, qu, phi = ~1, xi = ~1,
 
     ################################## Do the optimization....
 
-    o <- gpd.fit(y=y, th=th, X.phi=X.phi, X.xi=X.xi, penalty=prior, start=start, 
+    o <- gpdFit(y=y, th=th, X.phi=X.phi, X.xi=X.xi, penalty=prior, start=start, 
                  hessian = cov == "numeric",
                  priorParameters = priorParameters, maxit = maxit, trace = otrace)
 
@@ -155,6 +168,7 @@ function (y, data, th, qu, phi = ~1, xi = ~1,
     names(o$coefficients) <- c(paste("phi:", colnames(X.phi)), 
                                paste("xi:", colnames(X.xi)))
 
+    o$formulae <- list(phi=phi, xi=xi)
     o$par <- NULL
     o$rate <- rate
     o$call <- theCall
@@ -163,29 +177,31 @@ function (y, data, th, qu, phi = ~1, xi = ~1,
     o$X.xi <- X.xi
 	  o$priorParameters <- priorParameters
 	  if (missing(data)) {
-        data <- NULL
+        data <- allY
     }
     o$data <- data
                      
-    fittedScale <- exp(o$coefficients[1:ncol(o$X.phi)] %*% t(o$X.phi))
-    fittedShape <- o$coefficients[(ncol(o$X.phi) + 1):length(o$coefficients)] %*% t(o$X.xi)
+    fittedScale <- fittedGPDscale(o)
+    fittedShape <- fittedGPDshape(o)
     scaledY <- fittedShape * (o$y - o$threshold) / fittedScale
     o$residuals <- 1/fittedShape * log(1 + scaledY) # Standard exponential
-
+    if(any(fittedShape < -0.5)){
+      warning("fitted shape parameter xi < -0.5\n")
+    }
     o$loglik <- -o$value
     o$value <- NULL
     o$counts <- NULL
     oldClass(o) <- "gpd"
 
-    if (cov == "numeric") { 
-      o$cov <- solve(o$hessian) 
-    } else if (cov == "observed") { 
+    if (cov == "numeric") {
+      o$cov <- solve(o$hessian)
+    } else if (cov == "observed") {
       o$cov <- solve(info.gpd(o))
-    } else { 
-      stop("cov must be either 'numeric' or 'observed'") 
+    } else {
+      stop("cov must be either 'numeric' or 'observed'")
     }
 
-	  o$se <- sqrt(diag(o$cov))
+    o$se <- sqrt(diag(o$cov))
     if (method == "o"){
 		  o
     }
@@ -193,103 +209,91 @@ function (y, data, th, qu, phi = ~1, xi = ~1,
     ################################# Simulate from posteriors....
 
     else { # Method is "simulate"...
-        if (missing(jump.const)){
-            jump.const <- (2.4/sqrt(ncol(X.phi) + ncol(X.xi)))^2
+      proposal.fn <- switch(match.arg(proposal.dist),
+                            gaussian=rmvnorm,
+                            cauchy=.rmvcauchy,
+                            function () {stop("Bad proposal distribution")})
+      if (missing(jump.const)){
+        jump.const <- (2.4/sqrt(ncol(X.phi) + ncol(X.xi)))^2
+      }
+      u <- th
+
+      prior <- .make.mvn.prior(priorParameters)
+
+############################# Define log-likelihood
+
+      gpd.log.lik <- .make.gpd.loglikelihood(y, u, X.phi, X.xi)
+
+      log.lik <- function(param) {
+        gpd.log.lik(param) + prior(param)
+      }
+
+      # Need to check for convergence failure here. Otherwise, end up simulating
+      # proposals from distribution with zero variance in 1 dimension.
+       checkNA <- any(is.na(sqrt(diag(o$cov))))
+      if (checkNA){
+        stop("MAP estimates have not converged. Cannot proceed. Try a different prior" )
+      }
+
+      res <- matrix(ncol=ncol(X.phi) + ncol(X.xi), nrow=iter)
+      res[1,] <- if (missing(start)) { o$coefficients } else { start }
+
+
+      if (!exists(".Random.seed")){ runif(1)  }
+      seed <- .Random.seed # Retain and add to output
+
+      cov <- if (missing(jump.cov)) { o$cov } else { jump.cov }
+                                        # create proposals en bloc
+      proposals <- proposal.fn(iter,
+                               double(length(o$coefficients)),
+                               cov*jump.const)
+      last.cost <- log.lik(res[1,])
+      if (!is.finite(last.cost)) {
+        stop("Start is infeasible.")
+      }
+######################## Run the Metropolis algorithm...
+      acc <- 0
+      for(i in 2:iter){
+        if( verbose){
+          if( i %% trace == 0 ) cat(i, " steps taken\n" )
         }
-
-        u <- th
-
-	    ##################### Set up prior - account for differences between R & S+
-		if (is.R()){
-			prior <- dmvnorm
-		}
-		else {
-			prior <- function(x, mean, cov, log.=TRUE){ log(dmvnorm(x, mean, cov)) }
-		}
-
-	    ################# Set up proposal - account for differences bewteen R & S+
-	    if (is.R()){
-	    	proposal <- function(mean, sigma){
-		    	c(rmvnorm( 1 , mean, sigma = sigma ))
-	    	}
-	    }
-	    else {
-	    	proposal <- function(mean, sigma){
-	    		c(rmvnorm(1, mean, cov=sigma))
-	    	}
-	    }
-
-       ############################# Define log-likelihood
-
-        gpdlik <- # Positive loglikelihood
-        function(param, data, X.phi, X.xi){
-            phi <- colSums(param[1:ncol(X.phi)] * t(X.phi))
-            xi <- colSums(param[(ncol(X.phi) + 1):(ncol(X.phi) + ncol(X.xi))] * t(X.xi))
-
-            n <- length(data)
-            data <- xi * data / exp(phi) + 1
-            if(any(data <= 0)){ #| ( xi <= -.50 ) ) -(10^10)
-                -(10^10)
-            }
-            else  {
-                - sum(phi) - sum(log(data) * (1/xi + 1))
-            }
-        } # Close gpdlik <- function
-
-        # Need to check for convergence failure here. Otherwise, end up simulating
-        # proposals from distribution with zero variance in 1 dimension.
-        checkNA <- any(is.na(sqrt(diag(o$cov))))
-        if ( checkNA ){
-            stop( "MAP estimates have not converged. Cannot proceed. Try a different prior" )
+        prop <- proposals[i - 1,] + res[i - 1,]
+        top <- log.lik(prop)
+        delta <- top - last.cost
+        if (is.finite(top) && ((delta >= 0) ||
+                               (runif(1) <= exp(delta)))) {
+          res[i, ] <- prop
+          last.cost <- top
+          acc <- 1 + acc
+        } else {
+          res[ i , ] <- res[i-1,]
         }
+      } # Close for(i in 2:iter
 
-        res <- matrix( ncol=ncol(X.phi) + ncol(X.xi), nrow=iter )
+      acc <- acc / iter
+      if (acc < .1) {
+        warning("Acceptance rate in Metropolis algorithm is low.")
+      }
 
-        if (missing(start)) {
-            res[1, ] <- o$coefficients
-        }
-	    else { 
-            res[1, ] <- start
+      if (trace < iter) {
+        if(verbose) {
+          cat("Acceptance rate:", round( acc , 3 ) , "\n")
         }
+      }
 
-        if (!exists(".Random.seed")){ runif(1)  }
-        seed <- .Random.seed # Retain and add to output
+      if (missing(data)) {
+        data <- allY
+      }
+      res <- list(call=theCall, threshold=u , map = o,
+                  burn = burn, thin = thin,
+                  chains=res, y=y, data=data,
+                  X.phi = X.phi, X.xi = X.xi,
+                  acceptance=acc, seed=seed)
 
-        if (missing(jump.cov)){ cov <- o$cov }
-		else { cov <- jump.cov }
-        ######################## Run the Metropolis algorithm...
-        for(i in 2:iter){
-            if( verbose){
-                if( i %% trace == 0 ) cat(i, " steps taken\n" )
-            }
-			prop <- proposal(o$coefficients, cov*jump.const)
-            bottom <- prior(res[i - 1,], priorParameters[[1]], priorParameters[[2]], log=TRUE ) +
-                      gpdlik(res[ i - 1 , ] , y-u, X.phi, X.xi)
-            top <- prior(prop, priorParameters[[1]], priorParameters[[2]], log=TRUE) +
-                   gpdlik(prop, y-u, X.phi, X.xi)
-            r <- exp(top - bottom)
-            res[ i , ] <- if (runif(1) < r ){ prop }
-                          else{ res[i -1, ] }
-        } # Close for(i in 2:iter
-
-        acc <- length(unique(res[,1])) / iter
-        if (acc < .1){ warning("Acceptance rate in Metropolis algorithm is low.") }
-        if (trace < iter){
-            if(verbose) {
-                cat("Acceptance rate:", round( acc , 3 ) , "\n")
-            }
-        }
-
-        res <- list(call=theCall, threshold=u , map = o,
-                    burn = burn, thin = thin, 
-                    chains=res, y=y, data=data,
-                    X.phi = X.phi, X.xi = X.xi,
-					acceptance=acc, seed=seed 
-                    )
-        oldClass(res) <- "bgpd"
-        res <- thinAndBurn(res)
-        res
-    } # Close else 
+      oldClass(res) <- "bgpd"
+      res <- thinAndBurn(res)
+      res
+    } # Close else
 
 }
 
@@ -304,24 +308,28 @@ test.gpd <- function(){
 
   cparas <- c(7.44, 0.184)
   cse <- c(0.958432, 0.101151)
-  
+
   ccov <- matrix(c(.9188, -.0655, -.0655, .0102), nrow=2)
   cloglik <- -485.1
 
   mod <- gpd(rain, th=30, penalty="none")
   mod.coef <- coef(mod)
-  
+
   mod.coef[1] <- exp(mod.coef[1])
   names(mod.coef)[1] <- "sigma"
-  
+
   mod.loglik <- mod$loglik
   mod.cov22 <- mod$cov[2, 2]
 
-  checkEqualsNumeric(cparas, mod.coef, tolerance = tol,msg="gpd: parameter ests page 85 Coles")
-  checkEqualsNumeric(cse[2], mod$se[2], tolerance = tol,msg="gpd: standard errors page 85 Coles")
-  checkEqualsNumeric(ccov[2,2], mod$cov[2, 2], tolerance = tol,msg="gpd: Covariance page 85 Coles")
-  checkEqualsNumeric(cloglik, mod.loglik, tolerance = tol,msg="gpd: loglik page 85 Coles")
-  
+  checkEqualsNumeric(cparas, mod.coef, tolerance = tol,
+                     msg="gpd: parameter ests page 85 Coles")
+  checkEqualsNumeric(cse[2], mod$se[2], tolerance = tol,
+                     msg="gpd: standard errors page 85 Coles")
+  checkEqualsNumeric(ccov[2,2], mod$cov[2, 2], tolerance = tol,
+                     msg="gpd: Covariance page 85 Coles")
+  checkEqualsNumeric(cloglik, mod.loglik, tolerance = tol,
+                     msg="gpd: loglik page 85 Coles")
+
 ###################################################################
 #   Logical checks on the effect of Gaussian penalization. The smaller the
 #    variance, the more the parameter should be drawn towards the
@@ -335,8 +343,10 @@ test.gpd <- function(){
   mod1 <- gpd(rain, th=30, priorParameters=gp1)
   mod2 <- gpd(rain, th=30, priorParameters=gp2)
 
-  checkTrue(coef(mod)[2] > coef(mod1)[2],msg="gpd: Gaussian penalization xi being drawn to 0")
-  checkTrue(coef(mod1)[2] > coef(mod2)[2],msg="gpd: Gaussian penalization xi being drawn to 0")
+  checkTrue(coef(mod)[2] > coef(mod1)[2],
+            msg="gpd: Gaussian penalization xi being drawn to 0")
+  checkTrue(coef(mod1)[2] > coef(mod2)[2],
+            msg="gpd: Gaussian penalization xi being drawn to 0")
 
 # 2.2 Tests for phi being drawn to 0
 
@@ -346,8 +356,10 @@ test.gpd <- function(){
   mod3 <- gpd(rain, th=30, priorParameters=gp3)
   mod4 <- gpd(rain, th=30, priorParameters=gp4)
 
-  checkTrue(coef(mod)[1] > coef(mod3)[1],msg="gpd: Gaussian penalization phi being drawn to 0")
-  checkTrue(coef(mod3)[1] > coef(mod4)[1],msg="gpd: Gaussian penalization phi being drawn to 0")
+  checkTrue(coef(mod)[1] > coef(mod3)[1],
+            msg="gpd: Gaussian penalization phi being drawn to 0")
+  checkTrue(coef(mod3)[1] > coef(mod4)[1],
+            msg="gpd: Gaussian penalization phi being drawn to 0")
   
 # 2.3 Tests for xi being drawn to 1
   gp5 <- list(c(0, 1), diag(c(10^4, .25)))
@@ -356,8 +368,10 @@ test.gpd <- function(){
   mod5 <- gpd(rain, th=30, priorParameters=gp5)
   mod6 <- gpd(rain, th=30, priorParameters=gp6)
 
-  checkTrue(1 - coef(mod)[2] > 1 - coef(mod5)[2],msg="gpd: Gaussian penalization xi being drawn to 1")
-  checkTrue(1 - coef(mod1)[2] > 1 - coef(mod6)[2],msg="gpd: Gaussian penalization xi being drawn to 1")
+  checkTrue(1 - coef(mod)[2] > 1 - coef(mod5)[2],
+            msg="gpd: Gaussian penalization xi being drawn to 1")
+  checkTrue(1 - coef(mod1)[2] > 1 - coef(mod6)[2],
+            msg="gpd: Gaussian penalization xi being drawn to 1")
   
 # 2.4 Tests for phi being drawn to 4 (greater than mle for phi)
 
@@ -367,8 +381,10 @@ test.gpd <- function(){
   mod7 <- gpd(rain, th=30, priorParameters=gp7)
   mod8 <- gpd(rain, th=30, priorParameters=gp8)
 
-  checkTrue(4 - coef(mod)[1] > 4 - coef(mod7)[1],msg="gpd: Gaussian penalization phi being drawn to 4")
-  checkTrue(4 - coef(mod3)[1] > 4 - coef(mod8)[1],msg="gpd: Gaussian penalization phi being drawn to 4")
+  checkTrue(4 - coef(mod)[1] > 4 - coef(mod7)[1],
+            msg="gpd: Gaussian penalization phi being drawn to 4")
+  checkTrue(4 - coef(mod3)[1] > 4 - coef(mod8)[1],
+            msg="gpd: Gaussian penalization phi being drawn to 4")
   
 ###################################################################
 #   Logical checks on the effect of penalization using lasso or L1 penalization. The smaller the
@@ -383,8 +399,10 @@ test.gpd <- function(){
   mod1 <- gpd(rain, th=30, priorParameters=gp1, penalty="lasso")
   mod2 <- gpd(rain, th=30, priorParameters=gp2, penalty="lasso")
 
-  checkTrue(coef(mod)[2] > coef(mod1)[2],msg="gpd: lasso penalization xi being drawn to 0")
-  checkTrue(coef(mod1)[2] > coef(mod2)[2],msg="gpd: lasso penalization xi being drawn to 0")
+  checkTrue(coef(mod)[2] > coef(mod1)[2],
+            msg="gpd: lasso penalization xi being drawn to 0")
+  checkTrue(coef(mod1)[2] > coef(mod2)[2],
+            msg="gpd: lasso penalization xi being drawn to 0")
 
 # 2a.2 Tests for phi being drawn to 0
 
@@ -394,8 +412,10 @@ test.gpd <- function(){
   mod3 <- gpd(rain, th=30, priorParameters=gp3, penalty="lasso")
   mod4 <- gpd(rain, th=30, priorParameters=gp4, penalty="lasso")
 
-  checkTrue(coef(mod)[1] > coef(mod3)[1],msg="gpd: lasso penalization phi being drawn to 0")
-  checkTrue(coef(mod3)[1] > coef(mod4)[1],msg="gpd: lasso penalization phi being drawn to 0")
+  checkTrue(coef(mod)[1] > coef(mod3)[1],
+            msg="gpd: lasso penalization phi being drawn to 0")
+  checkTrue(coef(mod3)[1] > coef(mod4)[1],
+            msg="gpd: lasso penalization phi being drawn to 0")
   
 # 2a.3 Tests for xi being drawn to 1
   gp5 <- list(c(0, 1), solve(diag(c(10^4, .25))))
@@ -404,8 +424,10 @@ test.gpd <- function(){
   mod5 <- gpd(rain, th=30, priorParameters=gp5, penalty="lasso")
   mod6 <- gpd(rain, th=30, priorParameters=gp6, penalty="lasso")
 
-  checkTrue(1 - coef(mod)[2] > 1 - coef(mod5)[2],msg="gpd: lasso penalization xi being drawn to 1")
-  checkTrue(1 - coef(mod1)[2] > 1 - coef(mod6)[2],msg="gpd: lasso penalization xi being drawn to 1")
+  checkTrue(1 - coef(mod)[2] > 1 - coef(mod5)[2],
+            msg="gpd: lasso penalization xi being drawn to 1")
+  checkTrue(1 - coef(mod1)[2] > 1 - coef(mod6)[2],
+            msg="gpd: lasso penalization xi being drawn to 1")
   
 # 2a.4 Tests for phi being drawn to 4 (greater than mle for phi)
 
@@ -415,8 +437,10 @@ test.gpd <- function(){
   mod7 <- gpd(rain, th=30, priorParameters=gp7, penalty="lasso")
   mod8 <- gpd(rain, th=30, priorParameters=gp8, penalty="lasso")
 
-  checkTrue(4 - coef(mod)[1] > 4 - coef(mod7)[1],msg="gpd: lasso penalization phi being drawn to 4")
-  checkTrue(4 - coef(mod3)[1] > 4 - coef(mod8)[1],msg="gpd: lasso penalization phi being drawn to 4")
+  checkTrue(4 - coef(mod)[1] > 4 - coef(mod7)[1],
+            msg="gpd: lasso penalization phi being drawn to 4")
+  checkTrue(4 - coef(mod3)[1] > 4 - coef(mod8)[1],
+            msg="gpd: lasso penalization phi being drawn to 4")
 
 ########################################################
 # Tests on including covariates. Once more, gpd.fit in ismev
@@ -430,7 +454,8 @@ test.gpd <- function(){
 
   mod <- gpd(rainfall, th=30, data=d, phi= ~ time, penalty="none")
 
-  checkEqualsNumeric(-484.6, mod$loglik, tolerance = tol,msg="gpd: loglik Coles page 119")
+  checkEqualsNumeric(-484.6, mod$loglik, tolerance = tol,
+                     msg="gpd: loglik Coles page 119")
   
 ####################################################################
 # 3.1 Use liver data, compare with ismev. 
@@ -443,14 +468,21 @@ test.gpd <- function(){
 
   m <- model.matrix(~ ALT.B + dose, liver)
 
-  ismod <- .ismev.gpd.fit(liver$ALT.M, 
-                          threshold=quantile(liver$ALT.M, .7), 
-                          ydat = m, sigl=2:ncol(m), siglink=exp, show=FALSE)
+  ismod <- texmex:::.ismev.gpd.fit(liver$ALT.M,
+                                   threshold=quantile(liver$ALT.M, .7),
+                                   ydat = m, sigl=2:ncol(m),
+                                   siglink=exp, show=FALSE)
 
-  checkEqualsNumeric(ismod$mle, coef(mod), tolerance = tol,msg="gpd: covariates in phi only, point ests")
+  checkEqualsNumeric(ismod$mle,
+                     coef(mod),
+                     tolerance=tol,
+                     msg="gpd: covariates in phi only, point ests")
 
 # SEs for phi will not be same as for sigma, but we can test xi
-  checkEqualsNumeric(ismod$se[length(ismod$se)], mod$se[length(mod$se)], tolerance = tol,msg="gpd: covariates in phi only, standard errors")
+  checkEqualsNumeric(ismod$se[length(ismod$se)],
+                     mod$se[length(mod$se)],
+                     tolerance=tol,
+                     msg="gpd: covariates in phi only, standard errors")
 
 ######################################################################
 # 3.2 Test xi alone.
@@ -460,15 +492,21 @@ test.gpd <- function(){
 
   m <- model.matrix(~ ALT.B + dose, liver)
 
-  ismod <- .ismev.gpd.fit(log(liver$ALT.M / liver$ALT.B), 
-                          threshold=quantile(log(liver$ALT.M / liver$ALT.B), .7), 
-                          ydat = m, shl=2:ncol(m), show=FALSE)
+  ismod <- texmex:::.ismev.gpd.fit(log(liver$ALT.M / liver$ALT.B), 
+                                   threshold=quantile(log(liver$ALT.M / liver$ALT.B), .7), 
+                                   ydat = m, shl=2:ncol(m), show=FALSE)
   mco <- coef(mod)
   mco[1] <- exp(mco[1])
 
-  checkEqualsNumeric(ismod$mle, mco, tolerance = tol,msg="gpd: covariates in xi only: point ests")
+  checkEqualsNumeric(ismod$mle,
+                     mco,
+                     tolerance=tol,
+                     msg="gpd: covariates in xi only: point ests")
 # SEs for phi will not be same as for sigma, but we can test xi
-  checkEqualsNumeric(ismod$se[-1], mod$se[-1], tolerance = tol, msg="gpd: covariates in xi only: standard errors")
+  checkEqualsNumeric(ismod$se[-1],
+                     mod$se[-1],
+                     tolerance = tol,
+                     msg="gpd: covariates in xi only: standard errors")
 
 ######################################################################
 # 3.3 Test phi & xi simultaneously. Use simulated data.
@@ -479,10 +517,10 @@ test.gpd <- function(){
   # lengths of a and b should divide n exactly
   # returns data set size 2n made up of uniform variates (size n) below threshold u and 
   # gpd (size n) with scale parameter exp(a) and shape b above threshold u
-  { 
+  {
     gpd <- rgpd(n,exp(a),b,u=u)
     unif <- runif(n,u-10,u)
-    as.data.frame(cbind(a=a,b=b,y=c(gpd,unif))) 
+    as.data.frame(cbind(a=a,b=b,y=c(gpd,unif)))
   }
 
   mya <- seq(0.1,1,len=10)
@@ -491,11 +529,20 @@ test.gpd <- function(){
   m <- model.matrix(~ a+b, data)
   
   mod <- gpd(y,qu=0.7,data=data,phi=~a,xi=~b,penalty="none")
-  ismod <- .ismev.gpd.fit(data$y,threshold=quantile(data$y,0.7),
-                   ydat=m,shl=3,sigl=2,siglink=exp, show=FALSE)
+  ismod <- texmex:::.ismev.gpd.fit(data$y,
+                                   threshold=quantile(data$y,0.7),
+                                   ydat=m,shl=3,sigl=2,
+                                   siglink=exp,
+                                   show=FALSE)
 
-  checkEqualsNumeric(ismod$mle, coef(mod),tolerance = tol,msg="gpd: covariates in phi and xi: point ests")
-  checkEqualsNumeric(ismod$se, sqrt(diag(mod$cov)),tolerance = tol,msg="gpd: covariates in phi and xi: std errs")
+  checkEqualsNumeric(ismod$mle,
+                     coef(mod),
+                     tolerance = tol,
+                     msg="gpd: covariates in phi and xi: point ests")
+  checkEqualsNumeric(ismod$se,
+                     sqrt(diag(mod$cov)),
+                     tolerance = tol,
+                     msg="gpd: covariates in phi and xi: std errs")
 
 ####################################################################
 # Check that using priors gives expected behaviour when covariates are included.
@@ -512,8 +559,10 @@ test.gpd <- function(){
   mod1 <- gpd(y,qu=0.6,data=data,phi=~1,xi=~b,priorParameters=gp1)
   mod2 <- gpd(y,qu=0.6,data=data,phi=~1,xi=~b,priorParameters=gp2)
 
-  checkTrue(all(abs(coef(mod0)[2:3]) > abs(coef(mod1)[2:3])),msg="gpd: with covariates, xi drawn to zero")
-  checkTrue(abs(coef(mod1)[3]) > abs(coef(mod2)[3]),msg="gpd: with covariates, xi drawn to zero")
+  checkTrue(all(abs(coef(mod0)[2:3]) > abs(coef(mod1)[2:3])),
+            msg="gpd: with covariates, xi drawn to zero")
+  checkTrue(abs(coef(mod1)[3]) > abs(coef(mod2)[3]),
+            msg="gpd: with covariates, xi drawn to zero")
 
 # 2.2 Tests for phi being drawn to 0
 
@@ -531,8 +580,10 @@ test.gpd <- function(){
   mod4 <- gpd(y,qu=0.6,data=data,phi=~a,xi=~1,priorParameters=gp4)
   mod5 <- gpd(y,qu=0.6,data=data,phi=~a,xi=~1,priorParameters=gp5)
 
-  checkTrue(all(abs(coef(mod3)[1:2]) > abs(coef(mod4)[1:2])),msg="gpd: with covariates, phi being drawn to 0")
-  checkTrue(all(abs(coef(mod4)[1:2]) > abs(coef(mod5)[1:2])),msg="gpd: with covariates, phi being drawn to 0")
+  checkTrue(all(abs(coef(mod3)[1:2]) > abs(coef(mod4)[1:2])),
+            msg="gpd: with covariates, phi being drawn to 0")
+  checkTrue(all(abs(coef(mod4)[1:2]) > abs(coef(mod5)[1:2])),
+            msg="gpd: with covariates, phi being drawn to 0")
 
 # 2.3 Tests for xi being drawn to 2
   myb <- rep(c(-0.5,0.5),each=5)
@@ -545,8 +596,10 @@ test.gpd <- function(){
   mod7 <- gpd(y,qu=0.6,data=data,phi=~1,xi=~b,priorParameters=gp7)
   mod8 <- gpd(y,qu=0.6,data=data,phi=~1,xi=~b,priorParameters=gp8)
 
-  checkTrue(all(abs(2 - coef(mod6)[2:3]) > abs(2 - coef(mod7)[2:3])),msg="gpd: with covariates, xi drawn to 2")
-  checkTrue(all(abs(2 - coef(mod7)[2:3]) > abs(2 - coef(mod8)[2:3])),msg="gpd: with covariates, xi drawn to 2")
+  checkTrue(all(abs(2 - coef(mod6)[2:3]) > abs(2 - coef(mod7)[2:3])),
+            msg="gpd: with covariates, xi drawn to 2")
+  checkTrue(all(abs(2 - coef(mod7)[2:3]) > abs(2 - coef(mod8)[2:3])),
+            msg="gpd: with covariates, xi drawn to 2")
 
 # 2.4 Tests for phi being drawn to 4 
 
@@ -561,8 +614,10 @@ test.gpd <- function(){
   mod10 <- gpd(y,qu=0.6,data=data,phi=~a,xi=~1,priorParameters=gp10)
   mod11 <- gpd(y,qu=0.6,data=data,phi=~a,xi=~1,priorParameters=gp11)
 
-  checkTrue(abs(4 - coef(mod9)[2])  > abs(4 - coef(mod10)[2]),msg="gpd: with covariates, phi drawn to 4")
-  checkTrue(abs(4 - coef(mod10)[2]) > abs(4 - coef(mod11)[2]),msg="gpd: with covariates, phi drawn to 4")
+  checkTrue(abs(4 - coef(mod9)[2])  > abs(4 - coef(mod10)[2]),
+            msg="gpd: with covariates, phi drawn to 4")
+  checkTrue(abs(4 - coef(mod10)[2]) > abs(4 - coef(mod11)[2]),
+            msg="gpd: with covariates, phi drawn to 4")
 
 #*************************************************************
   postSum <- function(x){
@@ -575,28 +630,38 @@ test.gpd <- function(){
   save.seed <- .Random.seed
 
   set.seed(save.seed)
-  bmod <- gpd(ALT.M, data=liver, th=quantile(liver$ALT.M, .7), iter=1000,verbose=FALSE, method="sim")
+  bmod <- gpd(ALT.M, data=liver,
+              th=quantile(liver$ALT.M, .7),
+              iter=1000, thin=1, verbose=FALSE, method="sim")
   
   set.seed(save.seed)
-  bmod2 <- gpd(ALT.M, data=liver, th=quantile(liver$ALT.M, .7), iter=1000,verbose=FALSE, method="sim")
+  bmod2 <- gpd(ALT.M, data=liver,
+               th=quantile(liver$ALT.M, .7),
+               iter=1000, thin=1, verbose=FALSE, method="sim")
   
-  checkEqualsNumeric(bmod$param,bmod2$param,msg="gpd: test simulation reproducibility 1")
+  checkEqualsNumeric(bmod$param, bmod2$param,
+                     msg="gpd: test simulation reproducibility 1")
 
   set.seed(bmod$seed)
-  bmod3 <- gpd(ALT.M, data=liver, th=quantile(liver$ALT.M, .7), iter=1000,verbose=FALSE, method="sim")
-  checkEqualsNumeric(bmod$param, bmod3$param,msg="gpd: test simulation reproducibility 2")
+  bmod3 <- gpd(ALT.M, data=liver,
+               th=quantile(liver$ALT.M, .7),
+               iter=1000, thin=1, verbose=FALSE, method="sim")
+  checkEqualsNumeric(bmod$param, bmod3$param,
+                     msg="gpd: test simulation reproducibility 2")
 
 #*************************************************************  
 # 4.2. Logical test of burn-in
 
-  checkEqualsNumeric(nrow(bmod$chains) - bmod$burn, nrow(bmod$param),msg="gpd: Logical test of burn-in 1")
+  checkEqualsNumeric(nrow(bmod$chains) - bmod$burn, nrow(bmod$param),
+                     msg="gpd: Logical test of burn-in 1")
 
   iter <- sample(500:1000,1)
   burn <- sample(50,1)
   bmod2 <- gpd(ALT.M, data=liver, th=quantile(liver$ALT.M, .7),
-                iter=iter, burn=burn, verbose=FALSE, method="sim")
+                iter=iter, burn=burn, thin=1, verbose=FALSE, method="sim")
 
-  checkEqualsNumeric(iter-burn, nrow(bmod2$param),msg="gpd: Logical test of burn-in 2")
+  checkEqualsNumeric(iter-burn, nrow(bmod2$param),
+                     msg="gpd: Logical test of burn-in 2")
 
 #*************************************************************
 # 4.3. Logical test of thinning
@@ -606,102 +671,16 @@ test.gpd <- function(){
   bmod <- gpd(ALT.M, data=liver, th=quantile(liver$ALT.M, .7),
                iter=iter, thin = thin,verbose=FALSE, method="sim")
 
-  checkEqualsNumeric((nrow(bmod$chains) - bmod$burn) * thin, nrow(bmod$param),msg="gpd: Logical test of thinning 1")
+  checkEqualsNumeric((nrow(bmod$chains) - bmod$burn) * thin, nrow(bmod$param),
+                     msg="gpd: Logical test of thinning 1")
 
   thin <- 2
   iter <- 1000
   bmod <- gpd(ALT.M, data=liver, th=quantile(liver$ALT.M, .7),
                iter=iter, thin = thin, verbose=FALSE, method="sim")
 
-  checkEqualsNumeric((nrow(bmod$chains) - bmod$burn) / thin, nrow(bmod$param),msg="gpd: Logical test of thinning 1")
+  checkEqualsNumeric((nrow(bmod$chains) - bmod$burn) / thin, nrow(bmod$param),
+                     msg="gpd: Logical test of thinning 1")
 
-#*************************************************************  
-## Checks of gpd simulation. Centres of distributions and standard deviations 
-## should be similar to those coming out of gpd with the same penalty.
-## Posterior means are not the same as MAPs and SEs from Obs Information are
-## approximations, so allow some tolerance.
-
-  tol <- 0.1
-  tol.se <- 0.2
-# 4.4. Compare MAP and posterior summaries for simple model
-
-  mod <- gpd(ALT.M, data=liver, qu=.7)
-  bmod <- gpd(ALT.M, data=liver, th=quantile(liver$ALT.M, .7),verbose=FALSE, method="sim")
-
-  checkEqualsNumeric(coef(mod), postSum(bmod)[,1], tolerance=tol,msg="gpd: Compare MAP and posterior summaries for simple model - point ests")
-  checkEqualsNumeric(mod$se, postSum(bmod)[,2], tolerance=tol.se,msg="gpd: Compare MAP and posterior summaries for simple model - std errs")
-
-# 4.4a now not so simple model:
-
-  gp12 <- list(c(0, 0), diag(c(0.25, 0.25)))
-  gp13 <- list(c(1, 0.1), diag(c(0.05, 0.1)))
-
-  mod12 <- gpd(ALT.M,qu=0.7,data=liver,priorParameters=gp12)
-  mod13 <- gpd(ALT.M,qu=0.7,data=liver,priorParameters=gp13)
-  
-  bmod12 <- gpd(ALT.M, data=liver, th=quantile(liver$ALT.M, .7),verbose=FALSE, method="sim",priorParameters=gp12)
-  bmod13 <- gpd(ALT.M, data=liver, th=quantile(liver$ALT.M, .7),verbose=FALSE, method="sim",priorParameters=gp13)
-  
-  checkEqualsNumeric(coef(mod12), postSum(bmod12)[,1], tolerance=tol,msg="gpd: Compare MAP and posterior summaries for penalized model 1 - point ests")
-  checkEqualsNumeric(mod12$se, postSum(bmod12)[,2], tolerance=tol.se,msg="gpd: Compare MAP and posterior summaries for penalized model 1 - std errs")
-
-  checkEqualsNumeric(coef(mod13), postSum(bmod13)[,1], tolerance=tol,msg="gpd: Compare MAP and posterior summaries for penalized model 2 - point ests")
-  checkEqualsNumeric(mod13$se, postSum(bmod13)[,2], tolerance=tol.se,msg="gpd: Compare MAP and posterior summaries for penalized model 2 - std errs")
-#*************************************************************
-# 4.5. Covariates in phi
-
-  tol <- 0.01
-  tol.se <- 0.2
-
-  require(MASS,quiet=TRUE) # Use MASS because is ships with R and has no dependencies
-              # that don't ship with R.
-  liver <- liver
-  liver$ndose <- as.numeric(liver$dose)
-
-# function rlm : Fit a linear model by robust regression using an M estimator:
-
-  rmod <- rlm(log(ALT.M) ~ log(ALT.B) + dose, data=liver) 
-  liver$resids <- resid(rmod)
-
-  mod <- gpd(resids, data=liver, qu=.7, phi = ~ ndose)
-
-  bmod <- gpd(resids, data=liver, th=quantile(liver$resids, .7),
-              phi = ~ ndose,verbose=FALSE, method="sim")
-
-  checkEqualsNumeric(coef(mod), postSum(bmod)[,1], tolerance=tol,msg="gpd: Compare MAP and posterior summaries for Covariates in phi - point ests")
-  checkEqualsNumeric(mod$se, postSum(bmod)[,2], tolerance=tol.se,msg="gpd: Compare MAP and posterior summaries for Covariates in phi - std errs")
-
-#*************************************************************
-# 4.6. Covariates in xi
-
-  tol <- 0.02
-  tol.se <- 0.2
-
-  mod <- gpd(resids, data=liver, qu=.7, xi = ~ ndose)
-  bmod <- gpd(resids, data=liver, th=quantile(liver$resids, .7),
-               xi = ~ ndose,verbose=FALSE, method="sim")
-
-  checkEqualsNumeric(coef(mod), postSum(bmod)[,1], tolerance=tol,msg="gpd: Compare MAP and posterior summaries for Covariates in xi - point ests")
-  checkEqualsNumeric(mod$se, postSum(bmod)[,2], tolerance=tol.se,msg="gpd: Compare MAP and posterior summaries for Covariates in xi - std errs")  
-
-#*************************************************************
-# 4.7. Covariates in xi and phi
-
-  # A lot of faffing around led to the conclusion that the seed was an
-  # unfortunate choice. This usually passes with tol=.02, but fails with
-  # this seed (difference is 0.02282496. Change tol to 0.03
-
-  tol <- 0.03
-  tol.se <- 0.3
-
-  mod <- gpd(resids, data=liver, qu=.7,
-             xi = ~ ndose, 
-             phi = ~ ndose)
-  bmod <- gpd(resids, data=liver, th=quantile(liver$resids, .7),
-               xi = ~ ndose, 
-               phi = ~ ndose,verbose=FALSE, method="sim")
-
-  checkEqualsNumeric(coef(mod), postSum(bmod)[,1], tolerance=tol,msg="gpd: Compare MAP and posterior summaries for Covariates in phi and xi - point ests")
-  checkEqualsNumeric(mod$se, postSum(bmod)[,2], tolerance=tol.se,msg="gpd: Compare MAP and posterior summaries for Covariates in phi and xi - std errs")  
 }
 
