@@ -34,7 +34,7 @@ function (data, mth, mqu, penalty = "gaussian", maxit = 10000,
        else if (any(!is.element(nm, dimnames(data)[[2]])))
            stop("the names of priorParameters must match the column names of the data")
    }
-   
+
    wrapgpd <-function(i, x, mth, penalty, maxit, verbose, trace, priorParameters) {
        if (verbose)
            cat("Fitting model", i, "\n")
@@ -43,10 +43,10 @@ function (data, mth, mqu, penalty = "gaussian", maxit = 10000,
                dimnames(x)[[2]][i]]]]
        x <- c(x[, i])
        mth <- mth[i]
-   
+
        gpd(x, th=mth, penalty=penalty, priorParameters=priorParameters, maxit=maxit, trace=trace)
        }
-       
+
    modlist <- lapply(1:d, wrapgpd, x=data, penalty=penalty, mth=mth, verbose=verbose,
                         priorParameters=priorParameters,maxit=maxit,trace=trace)
    if (length(dimnames(data)[[2]]) == dim(data)[[2]]){
@@ -61,14 +61,14 @@ function (data, mth, mqu, penalty = "gaussian", maxit = 10000,
 
 test.migpd <- function(){
 
-# values from Heffernan and Tawn (2004) Table 4. 
+# values from Heffernan and Tawn (2004) Table 4.
 # Note values in published Table 4 for u_{Xi} in cols NO2 and NO Winter were reversed.
 
   htsummer <- rbind(mqu=c(43, 43, 66.1, 22, 46),
     mth = c(.9, .7, .7, .85, .7),
     sigma = c(15.8, 9.1, 32.2, 42.9, 22.8),
     xi = c(-.29, .01, .02, .08, .02))
-  
+
   htwinter <- rbind(mqu=c(28, 49, 151.6, 23, 53),
     mth = rep(.7, 5),
     sigma = c(6.2, 9.3, 117.4, 19.7, 37.5),
@@ -76,17 +76,17 @@ test.migpd <- function(){
 
   summer.gpd <- summary(migpd(summer, mqu=htsummer[2,],penalty="none"),verbose=FALSE)
   winter.gpd <- summary(migpd(winter, mqu=htwinter[2,],penalty="none"),verbose=FALSE)
-  
+
   tol <- c(1, 0.05, .5, 0.5)
   for(i in 1:4){
-    checkEqualsNumeric(htsummer[i,], summer.gpd[i,],tol=tol[i],msg=paste("migpd: Table 4 summer",i))
-    checkEqualsNumeric(htwinter[i,], winter.gpd[i,],tol=tol[i],msg=paste("migpd: Table 4 winter",i))
+    checkEqualsNumeric(htsummer[i,], summer.gpd[i,],tolerance=tol[i],msg=paste("migpd: Table 4 summer",i))
+    checkEqualsNumeric(htwinter[i,], winter.gpd[i,],tolerance=tol[i],msg=paste("migpd: Table 4 winter",i))
   }
-  
+
 # check excecution for 2-d data
 
-  wavesurge.fit <- migpd(wavesurge,mq=.7)
+  wavesurge.fit <- migpd(wavesurge,mqu=.7)
   checkEqualsNumeric(wavesurge.fit$models$wave$loglik,gpd(wavesurge$wave,qu=0.7)$loglik,
-                     tol=0.001,msg="migpd: 2-d data gpd fit wave")
-  
+                     tolerance=0.001,msg="migpd: 2-d data gpd fit wave")
+
 }
