@@ -2,7 +2,7 @@ ppgpd <-
 function( object , nsim = 1000, alpha = .050,
 		  xlab, ylab,  main, # labels and titles
 		  pch=1, col = 2, cex = .75, linecol = 4 ,
-		  intcol = 0, polycol=15, smooth = TRUE ){
+		  intcol = 0, polycol=15){
 	a <- object$coefficients
 	a[ 1 ] <- exp( a[ 1 ] )
 	u <- object$threshold
