@@ -13,7 +13,7 @@ function(x, ...){
   cat("\nLog-likelihood =",x$loglik,"\n")
   
 	cat("\nDependence structure parameter estimates:\n")
-	if (any(abs(x$coefficients)[3:4, ] > 10^(-6))){
+	if (!all(is.na(x$coefficients[3:4,])) & any(abs(x$coefficients)[3:4, ] > 10^(-6),na.rm=TRUE)){
 		print(x$coefficients[1:4,], ...)
 	} else {
 		print(x$coefficients[1:2, ], ...)
